@@ -32,7 +32,7 @@ HIVE = Hive(node=[HIVE_API_NODE], keys=[config['Global']['ACCOUNT_ACTIVE_KEY']])
 HIVE.chain_params['chain_id'] = 'beeab0de00000000000000000000000000000000000000000000000000000000'
 beem.instance.set_shared_blockchain_instance(HIVE)
 
-apiUrl = "https://engine.rishipanthee.com"
+apiUrl = 'https://engine.rishipanthee.com/'
 api = Api(url = apiUrl)
 
 ACCOUNT = Account(ACCOUNT_NAME)
